# Canary CMake Plugin

## Overview

The `canary_cmake` is a plugin for the [Canary](https://github.com/sandialabs/canary) testing framework. This plugin provides a test case generator for `CTestTestfile.cmake` files, which are generated by CMake. Additionally, it offers a reporter interface for generating and posting XML reports to CDash, enabling easy tracking of test results and project health.
